==> jc-1.4.0.tar.gz: gnu/xml/transform/TemplatesImpl.h <==
// class gnu.xml.transform.TemplatesImpl

// class file dependencies
// @dep_class 562578e7c2ccae6f gnu_xml_transform_TemplatesImpl
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_TemplatesImpl_H_
#define _JC_gnu_xml_transform_TemplatesImpl_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TransformerFactoryImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Properties$object;
struct _jc_javax_xml_transform_Transformer$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TemplatesImpl$sub_refs	_jc_gnu_xml_transform_TemplatesImpl$sub_refs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs	_jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$refs	_jc_gnu_xml_transform_TemplatesImpl$refs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$nonrefs	_jc_gnu_xml_transform_TemplatesImpl$nonrefs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$object	_jc_gnu_xml_transform_TemplatesImpl$object;

typedef const struct _jc_gnu_xml_transform_TemplatesImpl$vmethods	_jc_gnu_xml_transform_TemplatesImpl$vmethods;
typedef const struct _jc_gnu_xml_transform_TemplatesImpl$vtable	_jc_gnu_xml_transform_TemplatesImpl$vtable;
typedef const struct _jc_gnu_xml_transform_TemplatesImpl$vtype	_jc_gnu_xml_transform_TemplatesImpl$vtype;

// Constructors
extern void _jc_gnu_xml_transform_TemplatesImpl$method$_init$bd7d440595428f92(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *, struct _jc_gnu_xml_transform_TransformerFactoryImpl$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);

// Virtual methods
extern struct _jc_java_util_Properties$object *_jc_gnu_xml_transform_TemplatesImpl$method$getOutputProperties$78fe3a6873cb8d20(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *);
extern struct _jc_javax_xml_transform_Transformer$object *_jc_gnu_xml_transform_TemplatesImpl$method$newTransformer$1ea22dd68a9567ba(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TemplatesImpl$method_info$getOutputProperties$78fe3a6873cb8d20;
extern _jc_method _jc_gnu_xml_transform_TemplatesImpl$method_info$newTransformer$1ea22dd68a9567ba;

// Virtual methods structure
struct _jc_gnu_xml_transform_TemplatesImpl$vmethods {
	struct _jc_java_util_Properties$object	*(*getOutputProperties$78fe3a6873cb8d20)(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *);
	struct _jc_javax_xml_transform_Transformer$object	*(*newTransformer$1ea22dd68a9567ba)(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *);
};

// Vtable
struct _jc_gnu_xml_transform_TemplatesImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplatesImpl$vmethods	gnu_xml_transform_TemplatesImpl;
};

// Vtype
struct _jc_gnu_xml_transform_TemplatesImpl$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TemplatesImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplatesImpl$sub_refs {
	struct _jc_gnu_xml_transform_TransformerFactoryImpl$object	*factory;
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
	struct _jc_java_util_Properties$object	*outputProperties;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TemplatesImpl$refs {
    _jc_gnu_xml_transform_TemplatesImpl$sub_refs	gnu_xml_transform_TemplatesImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TemplatesImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs	gnu_xml_transform_TemplatesImpl;
};

// Object instance structure
struct _jc_gnu_xml_transform_TemplatesImpl$object {
	_jc_gnu_xml_transform_TemplatesImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TemplatesImpl$vtype	*vtype;
	_jc_gnu_xml_transform_TemplatesImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TemplatesImpl$vtype _jc_gnu_xml_transform_TemplatesImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TemplatesImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TemplatesImpl$class_object;

#endif	/* _JC_gnu_xml_transform_TemplatesImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/transform/TemplatesImpl.h <==
// class gnu.xml.transform.TemplatesImpl

// class file dependencies
// @dep_class 562578e7c2ccae6f gnu_xml_transform_TemplatesImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_TemplatesImpl_H_
#define _JC_gnu_xml_transform_TemplatesImpl_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TransformerFactoryImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Properties$object;
struct _jc_javax_xml_transform_Transformer$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TemplatesImpl$sub_refs	_jc_gnu_xml_transform_TemplatesImpl$sub_refs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs	_jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$refs	_jc_gnu_xml_transform_TemplatesImpl$refs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$nonrefs	_jc_gnu_xml_transform_TemplatesImpl$nonrefs;
typedef struct _jc_gnu_xml_transform_TemplatesImpl$object	_jc_gnu_xml_transform_TemplatesImpl$object;

typedef const struct _jc_gnu_xml_transform_TemplatesImpl$vmethods	_jc_gnu_xml_transform_TemplatesImpl$vmethods;
typedef const struct _jc_gnu_xml_transform_TemplatesImpl$vtable	_jc_gnu_xml_transform_TemplatesImpl$vtable;
typedef const struct _jc_gnu_xml_transform_TemplatesImpl$vtype	_jc_gnu_xml_transform_TemplatesImpl$vtype;

// Constructors
extern void _jc_gnu_xml_transform_TemplatesImpl$method$_init$bd7d440595428f92(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *, struct _jc_gnu_xml_transform_TransformerFactoryImpl$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_Properties$object *_jc_gnu_xml_transform_TemplatesImpl$method$getOutputProperties$78fe3a6873cb8d20(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_transform_Transformer$object *_jc_gnu_xml_transform_TemplatesImpl$method$newTransformer$1ea22dd68a9567ba(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TemplatesImpl$method_info$getOutputProperties$78fe3a6873cb8d20;
extern _jc_method _jc_gnu_xml_transform_TemplatesImpl$method_info$newTransformer$1ea22dd68a9567ba;

// Virtual methods structure
struct _jc_gnu_xml_transform_TemplatesImpl$vmethods {
	struct _jc_java_util_Properties$object	*(*getOutputProperties$78fe3a6873cb8d20)(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_transform_Transformer$object	*(*newTransformer$1ea22dd68a9567ba)(_jc_env *, struct _jc_gnu_xml_transform_TemplatesImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_TemplatesImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_TemplatesImpl$vmethods	gnu_xml_transform_TemplatesImpl;
};

// Vtype
struct _jc_gnu_xml_transform_TemplatesImpl$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TemplatesImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplatesImpl$sub_refs {
	struct _jc_gnu_xml_transform_TransformerFactoryImpl$object	*factory;
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
	struct _jc_java_util_Properties$object	*outputProperties;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TemplatesImpl$refs {
    _jc_gnu_xml_transform_TemplatesImpl$sub_refs	gnu_xml_transform_TemplatesImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TemplatesImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_TemplatesImpl$sub_nonrefs	gnu_xml_transform_TemplatesImpl;
};

// Object instance structure
struct _jc_gnu_xml_transform_TemplatesImpl$object {
	_jc_gnu_xml_transform_TemplatesImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TemplatesImpl$vtype	*vtype;
	_jc_gnu_xml_transform_TemplatesImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TemplatesImpl$vtype _jc_gnu_xml_transform_TemplatesImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TemplatesImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TemplatesImpl$class_object;

#endif	/* _JC_gnu_xml_transform_TemplatesImpl_H_ */
